TotalPhase Aardvark Python API
==============================

This package provides the TotalPhase Aardvark Python API modified for easy distribution and installation via PyPI.

Permission to modify and redistribute the Python language modules and associated shared object files has been granted explicitly by Total Phase, Inc. for use in this package.  Distribution and use of this package is subject to the license agreement provided in the LICENSE.txt file distributed with this package.
